@@ -5,7 +5,7 @@ use Dancer;
 setting serializer => 'JSON';
 
 get '/json' => sub {
-    to_json({foo => 'bar'}, pretty => 1);
+    to_json({foo => 'bar'}, { pretty => 1});
 };
 
 get '/' => sub {
